require 'omniauth-oauth2'
require 'faraday'
require 'faraday_middleware'

module OmniAuth
  module Strategies
    class Kounta < OmniAuth::Strategies::OAuth2
      AuthUrl = ENV["KOUNTA_AUTH_URL"] || "https://my.kounta.com"
      ApiUrl  = ENV["KOUNTA_API_URL"]  || "https://api.kounta.com"

      option :client_options, {
        :site          => AuthUrl,
        :authorize_url => "#{AuthUrl}/authorize",
        :token_url     => "#{ApiUrl}/v1/token.json"
      }

      info do
        {
          company: company_info,
          user: user_info
        }
      end

      def company_info
        @company_info ||= MultiJson.decode(kounta_api.get("/v1/companies/me.json").body)
      end

      def user_info
        company_id = company_info.dig("id")
        @user_info ||= MultiJson.decode(kounta_api.get("/v1/companies/#{company_id}/staff/me.json").body)
      end

      def kounta_api
        @kounta_api ||= Faraday.new(
          url: ApiUrl,
          headers: {
            "Accept" => "application/json",
            "Authorization" => "Bearer #{access_token.token}",
          }) { |b|
            b.use FaradayMiddleware::FollowRedirects
            b.adapter :net_http
          }
      end
    end
  end
end